@@ -5,6 +5,7 @@ class LogSerializer():
         self,
         execution_status: bool = False,
         message: str = "No message",
+        traceback: str = 'No traceback',
         execution_time: float = 0.0,
     ):
         # TODO: Add data validation.
@@ -12,4 +13,5 @@ class LogSerializer():
         # TODO: Add additional data serializer for sending any additional information as a JSON serializable dict.
         self.data['execution_status'] = execution_status
         self.data['execution_time'] = execution_time
-        self.data['message'] = message
\ No newline at end of file
+        self.data['message'] = message
+        self.data['traceback'] = traceback
\ No newline at end of file
